pub fn load_from_cache<T: DeserializeOwned>(filename: &str) -> Result<T>Expand description
Loads and deserializes data from a file in the cache directory. Checks if the cache file exists and is within the TTL (Time To Live).
pub fn load_from_cache<T: DeserializeOwned>(filename: &str) -> Result<T>Loads and deserializes data from a file in the cache directory. Checks if the cache file exists and is within the TTL (Time To Live).